@@ -106,7 +106,7 @@ class App:
 
         self.collections = []
         
-        self.app.add_route("/static/{filename}", self.static_app)
+        self.add_route("/static/{filename}", self.static_app)
 
     async def wsgi_app(self, scope, recieve, send):
         request = Request(scope, recieve=recieve)
